@@ -1,11 +1,11 @@
 /*-------------------------------------------------------------------------
  *
  * hash_query.c
- *		Track statement execution times across a whole database cluster.
+ *	  Track statement execution times across a whole database cluster.
  *
- * Portions Copyright © 2018-2020, Percona LLC and/or its affiliates
+ * Portions Copyright © 2018-2024, Percona LLC and/or its affiliates
  *
- * Portions Copyright (c) 1996-2020, PostgreSQL Global Development Group
+ * Portions Copyright (c) 1996-2024, PostgreSQL Global Development Group
  *
  * Portions Copyright (c) 1994, The Regents of the University of California
  *
@@ -19,9 +19,9 @@
 #include "pg_stat_monitor.h"
 
 static pgsmLocalState pgsmStateLocal;
-static PGSM_HASH_TABLE_HANDLE pgsm_create_bucket_hash(pgsmSharedState * pgsm, dsa_area *dsa);
+static PGSM_HASH_TABLE_HANDLE pgsm_create_bucket_hash(pgsmSharedState *pgsm, dsa_area *dsa);
 static Size pgsm_get_shared_area_size(void);
-static void InitializeSharedState(pgsmSharedState * pgsm);
+static void InitializeSharedState(pgsmSharedState *pgsm);
 
 #define PGSM_BUCKET_INFO_SIZE	(sizeof(TimestampTz) * pgsm_max_buckets)
 #define PGSM_SHARED_STATE_SIZE	(sizeof(pgsmSharedState) + PGSM_BUCKET_INFO_SIZE)
@@ -142,9 +142,9 @@ pgsm_startup(void)
 		 */
 		dsa_detach(dsa);
 
-	    pgsmStateLocal.pgsm_mem_cxt = AllocSetContextCreate(TopMemoryContext,
-                                                            "pg_stat_monitor local store",
-                                                            ALLOCSET_DEFAULT_SIZES);
+		pgsmStateLocal.pgsm_mem_cxt = AllocSetContextCreate(TopMemoryContext,
+															"pg_stat_monitor local store",
+															ALLOCSET_DEFAULT_SIZES);
 	}
 
 #ifdef BENCHMARK
@@ -161,7 +161,7 @@ pgsm_startup(void)
 }
 
 static void
-InitializeSharedState(pgsmSharedState * pgsm)
+InitializeSharedState(pgsmSharedState *pgsm)
 {
 	pg_atomic_init_u64(&pgsm->current_wbucket, 0);
 	pg_atomic_init_u64(&pgsm->prev_bucket_sec, 0);
@@ -172,7 +172,7 @@ InitializeSharedState(pgsmSharedState * pgsm)
  * Create the classic or dshahs hash table for storing the query statistics.
  */
 static PGSM_HASH_TABLE_HANDLE
-pgsm_create_bucket_hash(pgsmSharedState * pgsm, dsa_area *dsa)
+pgsm_create_bucket_hash(pgsmSharedState *pgsm, dsa_area *dsa)
 {
 	PGSM_HASH_TABLE_HANDLE bucket_hash;
 
@@ -238,7 +238,8 @@ pgsm_attach_shmem(void)
 	MemoryContextSwitchTo(oldcontext);
 }
 
-MemoryContext GetPgsmMemoryContext(void)
+MemoryContext
+GetPgsmMemoryContext(void)
 {
 	return pgsmStateLocal.pgsm_mem_cxt;
 }
@@ -287,7 +288,7 @@ pgsm_shmem_shutdown(int code, Datum arg)
 }
 
 pgsmEntry *
-hash_entry_alloc(pgsmSharedState * pgsm, pgsmHashKey * key, int encoding)
+hash_entry_alloc(pgsmSharedState *pgsm, pgsmHashKey *key, int encoding)
 {
 	pgsmEntry  *entry = NULL;
 	bool		found = false;
@@ -303,6 +304,8 @@ hash_entry_alloc(pgsmSharedState * pgsm, pgsmHashKey * key, int encoding)
 		memset(&entry->counters, 0, sizeof(Counters));
 		entry->query_text.query_pos = InvalidDsaPointer;
 		entry->counters.info.parent_query = InvalidDsaPointer;
+		entry->stats_since = GetCurrentTimestamp();
+		entry->minmax_stats_since = entry->stats_since;
 
 		/* set the appropriate initial usage count */
 		/* re-initialize the mutex each time ... we assume no one using it */
@@ -391,7 +394,7 @@ IsSystemOOM(void)
  */
 
 void *
-pgsm_hash_find_or_insert(PGSM_HASH_TABLE * shared_hash, pgsmHashKey * key, bool *found)
+pgsm_hash_find_or_insert(PGSM_HASH_TABLE * shared_hash, pgsmHashKey *key, bool *found)
 {
 #if USE_DYNAMIC_HASH
 	void	   *entry;
@@ -404,7 +407,7 @@ pgsm_hash_find_or_insert(PGSM_HASH_TABLE * shared_hash, pgsmHashKey * key, bool
 }
 
 void *
-pgsm_hash_find(PGSM_HASH_TABLE * shared_hash, pgsmHashKey * key, bool *found)
+pgsm_hash_find(PGSM_HASH_TABLE * shared_hash, pgsmHashKey *key, bool *found)
 {
 #if USE_DYNAMIC_HASH
 	return dshash_find(shared_hash, key, false);
