@@ -1,5 +1,5 @@
 CREATE EXTENSION pg_stat_monitor;
-Set pg_stat_monitor.pgsm_track='all';
+SET pg_stat_monitor.pgsm_track='all';
 SELECT pg_stat_monitor_reset();
 CREATE OR REPLACE FUNCTION add(int, int) RETURNS INTEGER AS
 $$
@@ -7,7 +7,7 @@ BEGIN
 	return (select $1 + $2);
 END; $$ language plpgsql;
 
-CREATE OR REPLACE function add2(int, int) RETURNS int as
+CREATE OR REPLACE FUNCTION add2(int, int) RETURNS INTEGER AS
 $$
 BEGIN
 	return add($1,$2);
