@@ -85,11 +85,22 @@ PGSM::append_to_debug_file($stdout);
 # Compare values for query 'SELECT * FROM t1' 
 ($cmdret, $stdout, $stderr) = $node->psql('postgres', 'SELECT PGSM.temp_blks_read != 0 FROM pg_stat_monitor AS PGSM WHERE PGSM.query LIKE \'%FROM t1%\';', extra_params => ['-Pformat=unaligned','-Ptuples_only=on']);
 trim($stdout);
-is($stdout,'t',"Check: shared_blks_hit should not be 0.");
+is($stdout,'t',"Check: temp_blks_read should not be 0.");
 
 ($cmdret, $stdout, $stderr) = $node->psql('postgres', 'SELECT PGSM.temp_blks_written != 0 FROM pg_stat_monitor AS PGSM WHERE PGSM.query LIKE \'%FROM t1%\';', extra_params => ['-Pformat=unaligned','-Ptuples_only=on']);
 trim($stdout);
-is($stdout,'t',"Check: temp_blks_read should not be 0.");
+is($stdout,'t',"Check: temp_blks_written should not be 0.");
+
+if ($PGSM::PG_MAJOR_VERSION >= 15)
+{
+    ($cmdret, $stdout, $stderr) = $node->psql('postgres', 'SELECT SUM(PGSM.temp_blk_read_time) != 0 FROM pg_stat_monitor AS PGSM WHERE PGSM.query LIKE \'%FROM t1%\';', extra_params => ['-Pformat=unaligned','-Ptuples_only=on']);
+    trim($stdout);
+    is($stdout,'t',"Check: temp_blk_read_time should not be 0.");
+
+    ($cmdret, $stdout, $stderr) = $node->psql('postgres', 'SELECT SUM(PGSM.temp_blk_write_time) != 0 FROM pg_stat_monitor AS PGSM WHERE PGSM.query LIKE \'%FROM t1%\'', extra_params => ['-Pformat=unaligned','-Ptuples_only=on']);
+    trim($stdout);
+    is($stdout,'t',"Check: temp_blk_write_time should not be 0.");
+}
 
 # DROP EXTENSION
 $stdout = $node->safe_psql('postgres', 'DROP EXTENSION pg_stat_monitor;', extra_params => ['-a']);
